/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.plot;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import nl.cloudfarming.client.area.AreaService;
import nl.cloudfarming.client.geoviewer.Category;
import nl.cloudfarming.client.geoviewer.ObjectLayer;
import nl.cloudfarming.client.model.Culture;
import nl.cloudfarming.client.model.DataProvider;

/**
 * A layer for cultures of a specific year
 * 
 * @author Gerben Feenstra
 */
public class CulturesLayer extends ObjectLayer<CultureLayerObject> {

    /**
     * The date of this Cultures layer. Only cultures with the same date (year) will be shown in this layer
     */
    private final Date date;
    
    public CulturesLayer(final String nodeName, final Date date, final DataProvider dp) {
        super(new PlotPalette(), Category.AREA, nodeName, dp,true);
        this.date = date;
        if (getObjects().size() > 0) {
            clearObjects();
        }

        List<CultureLayerObject> objects = new ArrayList<CultureLayerObject>();

        AreaService areaService = new PlotAreaService();
        for (Culture culture : areaService.findCulturesByDate(this.date)) {
            objects.add(new CultureLayerObject(culture));
        }
        addObjects(objects);
    }
}
