/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.plot;

import java.beans.IntrospectionException;
import nl.cloudfarming.client.area.plot.explorer.PlotRootNode;
import java.util.Date;
import java.util.List;
import javax.persistence.Query;
import javax.swing.ActionMap;
import javax.swing.text.DefaultEditorKit;
import nl.cloudfarming.client.area.AreaService;
import nl.cloudfarming.client.model.CommonModelService;
import nl.cloudfarming.client.model.DataProvider;
import nl.cloudfarming.client.model.Field;
import nl.cloudfarming.client.model.Plot;
import nl.cloudfarming.client.model.PlotFile;
import org.openide.explorer.ExplorerManager;
import org.openide.explorer.ExplorerUtils;
import org.openide.util.Exceptions;
import org.openide.util.NbBundle;
import org.openide.util.lookup.ServiceProvider;
import org.openide.util.lookup.ServiceProviders;

/**
 *
 * @author Timon Veenstra
 */
@ServiceProviders(value = {
    @ServiceProvider(service = DataProvider.class),
    @ServiceProvider(service = AreaService.class),
    @ServiceProvider(service = PlotAreaService.class)
})
public class PlotAreaService extends CommonModelService implements AreaService {
    
    @Override
    final protected String getModuleName() {
        return AreaPlotModule.MODULE_NAME;
    }

    final public List<Plot> findAllCurrentPlots() {
        startTransaction();
        Query query = getEntityManager().createNamedQuery("findAllValidPLots");
        query.setParameter("date", new Date());
        return query.getResultList();
    }

    @Override
    final public void createNewPlot(final Plot plot) {
        persistInTransaction(plot);
    }

    @Override
    final public void savePlotChanges(final Plot plot) {
        mergeAndPersistInTransaction(plot);
    }

    @Override
    final public void createNewPlotFile(final PlotFile plotFile) {
        persistInTransaction(plotFile);
    }

    @Override
    final public void createNewField(final Field field) {
        persistInTransaction(field);
    }

    @Override
    final protected void initExplorer() {
        try {
            ExplorerManager manager = new ExplorerManager();
            manager.setRootContext(new PlotRootNode(new PlotLayer("plot.node.name", this)));
            manager.getRootContext().setDisplayName(NbBundle.getMessage(this.getClass(), "plot_explorer.rootnode"));

            ActionMap map = new ActionMap();
            map.put(DefaultEditorKit.copyAction, ExplorerUtils.actionCopy(manager));
            map.put(DefaultEditorKit.cutAction, ExplorerUtils.actionCut(manager));
            map.put(DefaultEditorKit.pasteAction, ExplorerUtils.actionPaste(manager));
            map.put("delete", ExplorerUtils.actionDelete(manager, true)); // or false

            setExplorerManager(manager, map);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
        }
    }
}
