/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.plot.explorer;

import java.beans.IntrospectionException;
import java.util.List;
import nl.cloudfarming.client.area.AreaEventKey;
import nl.cloudfarming.client.area.plot.AreaPlotModule;
import nl.cloudfarming.client.area.plot.PlotAreaService;
import nl.cloudfarming.client.area.plot.PlotLayer;
import nl.cloudfarming.client.area.plot.PlotLayerObject;
import nl.cloudfarming.client.model.Plot;
import nl.cloudfarming.eventbus.GuiEvent;
import nl.cloudfarming.eventbus.GuiEventBus;
import nl.cloudfarming.eventbus.GuiEventKey;
import nl.cloudfarming.eventbus.GuiEventListener;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.Lookup;

/**
 *
 * @author Timon Veenstra
 */
public class PlotNodeFactory extends ChildFactory<Plot> {

    private PlotAreaService service;
    private final PlotLayer layer;


    public PlotNodeFactory(PlotLayer layer) {
        this.layer = layer;
        GuiEventBus.addListener(new GuiEventListener() {

            @Override
            public void onEvent(GuiEvent event) {
                refresh(true);
            }

            @Override
            public boolean listensTo(GuiEventKey guiEventKey) {
                return guiEventKey.equals(AreaEventKey.PLOTS_IMPORTED);
            }

            @Override
            public String getModuleName() {
                return AreaPlotModule.MODULE_NAME;
            }
        });
    }

    @Override
    protected Node createNodeForKey(Plot key) {
        try {
            PlotLayerObject layerObject = new PlotLayerObject(key);
            layer.addObject(layerObject);
            return new PlotNode(this.layer,layerObject, getService());
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }

    @Override
    protected boolean createKeys(List<Plot> toPopulate) {
        //TODO should be findAllCurrentPlots()
        toPopulate.addAll(getService().findAllPlots());
        return true;
    }

    public PlotAreaService getService() {
        if (this.service == null) {
            this.service = Lookup.getDefault().lookup(PlotAreaService.class);
        }
        return this.service;
    }

    public void setService(PlotAreaService service) {
        this.service = service;
    }
}
