/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.plot.shape;

import java.util.ArrayList;
import java.util.List;
import javax.swing.ActionMap;
import nl.cloudfarming.client.area.plot.AreaPlotModule;
import nl.cloudfarming.client.model.Bean;
import nl.cloudfarming.client.model.CommonModelService;
import nl.cloudfarming.client.model.PlotFile;
import nl.cloudfarming.client.model.Shape;
import org.openide.explorer.ExplorerManager;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node;

/**
 *
 * @author Timon Veenstra
 */
public class ImportDataProvider extends CommonModelService {

    private final PlotFile plotFile;
    private ImportLayer importLayer;
    private final List<Shape> shapes = new ArrayList<Shape>();

    public ImportDataProvider(PlotFile plotFile) {
        this.plotFile = plotFile;
    }

    @Override
    protected void initExplorer() {
        ExplorerManager manager = new ExplorerManager();
        setExplorerManager(manager, new ActionMap());
    }

    @Override
    protected String getModuleName() {
        return AreaPlotModule.MODULE_NAME;
    }

    @Override
    public void save(Bean bean) {
        // shape objects cannot be persisted
    }

    /**
     * get the import layer containing the imported shapes
     * 
     * @return import layer
     */
    public ImportLayer getLayer() {
        return importLayer;
    }

    /**
     * get the list with managed shapes
     * @return
     */
    public List<Shape> getShapes() {
        return shapes;
    }

    /**
     * add a shape to the list of managed shapes
     * 
     * @param shape
     */
    public void addShape(Shape shape){
        shapes.add(shape);
    }

    /**
     * method to indicate that the import has finished
     * A layer will be constructed based on the added shapes
     * and a node hierarchy will be created.
     */
    public void finished(){
        importLayer = new ImportLayer(plotFile, this);
        ShapeNodeFactory shapeNodeFactory = new ShapeNodeFactory(importLayer);
        shapeNodeFactory.setService(this);
        getExplorerManager().setRootContext(new AbstractNode(Children.create(shapeNodeFactory, true)));
    }

    /**
     * get a list with shape nodes managed by this data provider
     *
     * @return list with shape nodes
     */
    public List<ShapeNode> getShapeNodes(){
        List<ShapeNode> nodes = new ArrayList<ShapeNode>();
        for (Node node: getExplorerManager().getRootContext().getChildren().getNodes()){
            if (node instanceof ShapeNode){
                nodes.add((ShapeNode)node);
            }
        }
        return nodes;
    }

}
