/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.plot.shape;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.beans.PropertyVetoException;
import java.beans.VetoableChangeListener;
import nl.cloudfarming.client.area.plot.MarkAllShapesAsAction;
import nl.cloudfarming.client.area.plot.PlotPalette;
import nl.cloudfarming.client.area.plot.SaveImportLayerAction;
import nl.cloudfarming.client.area.plot.ShapeLayerObject;
import nl.cloudfarming.client.area.plot.shape.ImportDataProvider;
import nl.cloudfarming.client.area.plot.shape.ShapeNode;
import nl.cloudfarming.client.geoviewer.Category;
import nl.cloudfarming.client.geoviewer.LayerAction;
import nl.cloudfarming.client.geoviewer.ObjectLayer;
import nl.cloudfarming.client.model.PlotFile;
import org.openide.explorer.ExplorerManager;
import org.openide.nodes.Node;

/**
 * The importLayer containes shapes from an imported shapefile.
 * The layername is based on the filename of the imported shapefile and so it
 * is intended that each imported shapefile gets placed on a separate layer.
 *
 * The importlayer defines actions for (for example but not exclusive) saving the shapes to
 * more permanent layers.
 *
 * @author Timon Veenstra
 */
public class ImportLayer extends ObjectLayer<ShapeLayerObject> {

    private final PlotFile plotFile;

    public ImportLayer(final PlotFile plotFile, final ImportDataProvider dataProvider) {
        super(new PlotPalette(), Category.AREA, plotFile.getFileName(), dataProvider, true);
        this.plotFile = plotFile;
        dataProvider.getExplorerManager().addPropertyChangeListener(new PropertyChangeListener() {

            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                if (ExplorerManager.PROP_ROOT_CONTEXT.equals(evt.getPropertyName())) {
                    for (ShapeNode node : dataProvider.getShapeNodes()) {
                        addObject(node.getLayerObject());
                    }
                }
            }
        });
    }

    /**
     * Return the plotFile represented by this importlayer
     * @return The plotFile represented by this importlayer
     */
    final public PlotFile getPlotFile() {
        return plotFile;
    }

    @Override
    public LayerAction[] getActions() {
        return new LayerAction[]{new SaveImportLayerAction(), new MarkAllShapesAsAction()};
    }
}
