/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.plot.shape;

import java.beans.IntrospectionException;
import java.util.List;
import nl.cloudfarming.client.area.AreaEventKey;
import nl.cloudfarming.client.area.plot.AreaPlotModule;
import nl.cloudfarming.client.area.plot.ShapeLayerObject;
import nl.cloudfarming.client.model.Plot;
import nl.cloudfarming.client.model.Shape;
import nl.cloudfarming.eventbus.GuiEvent;
import nl.cloudfarming.eventbus.GuiEventBus;
import nl.cloudfarming.eventbus.GuiEventKey;
import nl.cloudfarming.eventbus.GuiEventListener;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;

/**
 *
 * @author Timon Veenstra
 */
public class ShapeNodeFactory extends ChildFactory<Shape> {

    private ImportDataProvider service;
    private final ImportLayer layer;

    public ShapeNodeFactory(ImportLayer layer) {
        this.layer = layer;
    }

    @Override
    protected Node createNodeForKey(Shape key) {
        try {
            ShapeLayerObject layerObject = new ShapeLayerObject(key);
            layer.addObject(layerObject);
            return new ShapeNode(this.layer, layerObject, service);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }

    @Override
    protected boolean createKeys(List<Shape> toPopulate) {
        assert service != null;
        toPopulate.addAll(service.getShapes());
        return true;
    }

    public void setService(ImportDataProvider service) {
        this.service = service;
    }
}
